==> ultracopier-src-2.2.6.8.tar.xz: ultracopier-src/plugins/Themes/Oxygen2/Languages/de/translation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de" sourcelanguage="en">
<context>
    <name>QObject</name>
    <message>
        <location filename="../../radialMap/map.cpp" line="108"/>
        <source>%1 files</source>
        <translation>%1 Dateien</translation>
    </message>
    <message numerus="yes">
        <location filename="../../radialMap/map.cpp" line="204"/>
        <source>%n file(s), with an average size of %1</source>
        <comment>file</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RadialMap::Widget</name>
    <message numerus="yes">
        <location filename="../../radialMap/widgetEvents.cpp" line="194"/>
        <location filename="../../radialMap/widgetEvents.cpp" line="196"/>
        <source> into %n file(s)</source>
        <comment>file</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Themes</name>
    <message>
        <location filename="../../interface.cpp" line="293"/>
        <location filename="../../interface.cpp" line="314"/>
        <source>Buy the Ultimate version to fund development</source>
        <translation>Kaufe die Ultimate Version um die Entwicklung zu finanzieren</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="293"/>
        <location filename="../../interface.cpp" line="314"/>
        <source>Register your key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="525"/>
        <source>File %1/%2, size: %3/%4</source>
        <translation>Datei %1/%2, Größe:%3/%4</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="832"/>
        <source>Copy list</source>
        <translation>Zu kopierende Dateien</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="834"/>
        <source>Move list</source>
        <translation>Zu verschiebende Dateien</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1335"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Nicht schließen, wenn Fehler aufgetreten sind</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1336"/>
        <source>Never close</source>
        <translation>Niemals schließen</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1337"/>
        <source>Always close</source>
        <translation>Immer schließen</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1339"/>
        <source>File Name, 0KB</source>
        <translation>Dateiname, 0KB</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1550"/>
        <location filename="../../interface.cpp" line="1562"/>
        <location filename="../../interface.cpp" line="1574"/>
        <source>Select a color</source>
        <translation>Farbe auswählen</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1662"/>
        <location filename="../../interface.cpp" line="1673"/>
        <location filename="../../interface.cpp" line="1682"/>
        <source>%1 %2% of %3 into %4 files</source>
        <translation>%1 %2 von %3 in %4 Dateien</translation>
    </message>
</context>
<context>
    <name>ThemesFactory</name>
    <message>
        <location filename="../../ThemesFactory.cpp" line="320"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Nicht schließen, wenn Fehler aufgetreten sind</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="321"/>
        <source>Never close</source>
        <translation>Niemals schließen</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="322"/>
        <source>Always close</source>
        <translation>Immer schließen</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="518"/>
        <location filename="../../ThemesFactory.cpp" line="533"/>
        <location filename="../../ThemesFactory.cpp" line="548"/>
        <source>Select a color</source>
        <translation>Wählen Sie eine Farbe</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="420"/>
        <source>From:</source>
        <translation>Von:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="301"/>
        <source>&amp;More</source>
        <translation>&amp;Mehr</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="321"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="482"/>
        <source>&amp;Skip</source>
        <translation>Über&amp;springen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="493"/>
        <source>&amp;Cancel</source>
        <translation>Abbrechen (&amp;C)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="570"/>
        <source>Transfer list</source>
        <translation>Dateiliste</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="726"/>
        <source>Delete the selected items</source>
        <translation>Ausgewählte Einträge löschen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="781"/>
        <source>Export the transfer list</source>
        <translation>Dateiliste exportieren</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="807"/>
        <source>Import the transfer list</source>
        <translation>Dateiliste importieren</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="862"/>
        <source>Previous</source>
        <translation>Vorherige</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="869"/>
        <source>Next</source>
        <translation>Nächste</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="982"/>
        <source>Interface</source>
        <translation>Darstellungsoptionen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="593"/>
        <source>Move the selected items to the top</source>
        <translation>Ausgewählte Einträge an den Listenanfang verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="232"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="252"/>
        <source>100MB+</source>
        <translation>100MB+</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="389"/>
        <source>Close on transfer completion</source>
        <translation>Am Ende des Transfers schließen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="527"/>
        <source>Limit copy speed to:</source>
        <translation>Begrenze Kopiergeschwindigkeit auf:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="619"/>
        <source>Move up the selected items</source>
        <translation>Ausgewählte Einträge einen Platz nach oben verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="645"/>
        <source>Move down the selected items</source>
        <translation>Ausgewählte Einträge einen Platz nach unten verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="671"/>
        <source>Move the selected items to the bottom</source>
        <translation>Ausgewählte Einträge an das Listenende verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="697"/>
        <source>Add file/folder</source>
        <translation>Datei/Ordner hinzufügen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="752"/>
        <source>Search</source>
        <translation>In Dateiliste suchen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="904"/>
        <location filename="../../interface.ui" line="973"/>
        <source>Error</source>
        <translation>Fehlerprotokoll</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="924"/>
        <source>Export the errors into transfer list</source>
        <translation>Fehlgeschlagene Dateien exportieren</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="963"/>
        <source>Source</source>
        <translation>Quelle</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="968"/>
        <source>Destination</source>
        <translation>Ziel</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1028"/>
        <source>Add file</source>
        <translation>Datei hinzufügen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1037"/>
        <source>Add folder</source>
        <translation>Ordner hinzufügen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1046"/>
        <source>Move file(s)</source>
        <translation>Datei(en) verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1055"/>
        <source>Move folder</source>
        <translation>Ordner verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1064"/>
        <source>Copy file(s)</source>
        <translation>Datei(en) kopieren</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1073"/>
        <source>Copy folder</source>
        <translation>Verzeichnis kopieren</translation>
    </message>
</context>
<context>
    <name>themesOptions</name>
    <message>
        <location filename="../../themesOptions.ui" line="293"/>
        <source>Show dual progression</source>
        <translation>Zweifachen Fortschrittsbalken anzeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="245"/>
        <source>Show speed as main information</source>
        <translation>Geschwindigkeitsbegrenzungsschieberegler anzeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="44"/>
        <source>Use</source>
        <translation>Benutzung</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="110"/>
        <source>Start with the &quot;more button&quot; pushed</source>
        <translation>Standardmäßig &quot;Mehr&quot; Informationen anzeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="57"/>
        <source>Minimize on close to systray</source>
        <translation>Beim Schließen ins Systray minimieren</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="80"/>
        <source>At the end of the copy</source>
        <translation>Am Ende des Vorgangs</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="70"/>
        <location filename="../../themesOptions.ui" line="87"/>
        <source>Limit copy speed to</source>
        <translation>Begrenze Übertragungsgeschwindigkeit auf</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="117"/>
        <source>Start minimized</source>
        <translation>Minimiert starten</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="144"/>
        <source>Position at start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="239"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="332"/>
        <source>Click to edit the color</source>
        <translation>Zum Bearbeiten der Farbe klicken</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="97"/>
        <source> KB/s</source>
        <translation> KB/s</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="204"/>
        <source>Dark UI</source>
        <translation>Dunkles Design</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="212"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="217"/>
        <source>Save as previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="222"/>
        <source>At Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="277"/>
        <source>Display</source>
        <translation>Anzeige</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="283"/>
        <source>Speed with progress bar</source>
        <translation>Geschwindigkeit als Fortschrittsbalken anzeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="313"/>
        <source>Progression color</source>
        <translation>Farbe des Fortschrittsbalken</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="303"/>
        <source>Show progression in the title</source>
        <translation>Fortschritt im Fenstertitel zeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="137"/>
        <source>Always on top</source>
        <translation>Fenster immer im Vordergrund  halten</translation>
    </message>
</context>
</TS>

==> ultracopier-src-3.0.0.8.tar.xz: ultracopier-src/plugins/Themes/Oxygen2/Languages/de/translation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_AT">
<context>
    <name>QObject</name>
    <message>
        <location filename="../../radialMap/map.cpp" line="108"/>
        <source>%1 files</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../../radialMap/map.cpp" line="204"/>
        <source>%n file(s), with an average size of %1</source>
        <comment>file</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RadialMap::Widget</name>
    <message numerus="yes">
        <location filename="../../radialMap/widgetEvents.cpp" line="194"/>
        <location filename="../../radialMap/widgetEvents.cpp" line="196"/>
        <source> into %n file(s)</source>
        <comment>file</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Themes</name>
    <message>
        <location filename="../../interface.cpp" line="550"/>
        <source>File %1/%2, size: %3/%4</source>
        <translation>Datei %1/%2, Größe:%3/%4</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1341"/>
        <source>Always close</source>
        <translation>Immer schließen</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1343"/>
        <source>File Name, 0KB</source>
        <translation>Dateiname, 0KB</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1340"/>
        <source>Never close</source>
        <translation>Niemals schließen</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="836"/>
        <source>Copy list</source>
        <translation>Kopier Liste</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="291"/>
        <location filename="../../interface.cpp" line="297"/>
        <location filename="../../interface.cpp" line="325"/>
        <location filename="../../interface.cpp" line="331"/>
        <source>Buy the Ultimate version to fund development</source>
        <translation>Kaufen Sie die Ultimate Version, um die Entwicklung des Programms zu unterstützen</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="295"/>
        <location filename="../../interface.cpp" line="329"/>
        <source>Ultimate version have more performance via OS native copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="306"/>
        <location filename="../../interface.cpp" line="339"/>
        <source>Register your key</source>
        <translation>Produktschlüssel registrieren</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="838"/>
        <source>Move list</source>
        <translation>Verschieben Liste</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1339"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Nicht schließen, wenn Fehler aufgetreten sind</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1554"/>
        <location filename="../../interface.cpp" line="1566"/>
        <location filename="../../interface.cpp" line="1578"/>
        <source>Select a color</source>
        <translation>Farbe auswählen</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1666"/>
        <location filename="../../interface.cpp" line="1677"/>
        <location filename="../../interface.cpp" line="1686"/>
        <source>%1 %2% of %3 into %4 files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemesFactory</name>
    <message>
        <location filename="../../ThemesFactory.cpp" line="324"/>
        <source>Always close</source>
        <translation>Immer schließen</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="323"/>
        <source>Never close</source>
        <translation>Niemals schließen</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="322"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Nicht schließen, wenn Fehler aufgetreten sind</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="520"/>
        <location filename="../../ThemesFactory.cpp" line="535"/>
        <location filename="../../ThemesFactory.cpp" line="550"/>
        <source>Select a color</source>
        <translation>Farbe auswählen</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="968"/>
        <source>Destination</source>
        <translation>Ziel</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="869"/>
        <source>Next</source>
        <translation>Nächste</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="301"/>
        <source>&amp;More</source>
        <translation>&amp;Mehr</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="482"/>
        <source>&amp;Skip</source>
        <translation>Über&amp;springen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="904"/>
        <location filename="../../interface.ui" line="973"/>
        <source>Error</source>
        <translation>Fehlerprotokoll</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="420"/>
        <source>From:</source>
        <translation>Von:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="726"/>
        <source>Delete the selected items</source>
        <translation>Ausgewählte Einträge löschen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="321"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="697"/>
        <source>Add file/folder</source>
        <translation>Datei/Ordner hinzufügen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="807"/>
        <source>Import the transfer list</source>
        <translation>Dateiliste importieren</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="781"/>
        <source>Export the transfer list</source>
        <translation>Dateiliste exportieren</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="752"/>
        <source>Search</source>
        <translation>In Dateiliste suchen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="963"/>
        <source>Source</source>
        <translation>Quelle</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1073"/>
        <source>Copy folder</source>
        <translation>Kopiere Ordner</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1055"/>
        <source>Move folder</source>
        <translation>Verschiebe Ordner</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1037"/>
        <source>Add folder</source>
        <translation>Ordner hinzufügen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="570"/>
        <source>Transfer list</source>
        <translation>Transferliste</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1064"/>
        <source>Copy file(s)</source>
        <translation>Kopiere Dateie(n)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="862"/>
        <source>Previous</source>
        <translation>Vorherige</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="389"/>
        <source>Close on transfer completion</source>
        <translation>Am Ende des Transfers schließen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1046"/>
        <source>Move file(s)</source>
        <translation>Verschiebe Dateie(n)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1028"/>
        <source>Add file</source>
        <translation>Datei hinzufügen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="493"/>
        <source>&amp;Cancel</source>
        <translation>Abbrechen (&amp;C)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="671"/>
        <source>Move the selected items to the bottom</source>
        <translation>Ausgewählte Einträge an das Listenende verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="645"/>
        <source>Move down the selected items</source>
        <translation>Ausgewählte Einträge einen Platz nach unten verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="982"/>
        <source>Interface</source>
        <translation>Darstellungsoptionen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="593"/>
        <source>Move the selected items to the top</source>
        <translation>Ausgewählte Einträge an den Listenanfang verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="619"/>
        <source>Move up the selected items</source>
        <translation>Ausgewählte Einträge einen Platz nach oben verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="527"/>
        <source>Limit copy speed to:</source>
        <translation>Begrenze Kopiergeschwindigkeit auf:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="924"/>
        <source>Export the errors into transfer list</source>
        <translation>Exportiere Fehler in Transferliste</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="232"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="252"/>
        <source>100MB+</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>themesOptions</name>
    <message>
        <location filename="../../themesOptions.ui" line="44"/>
        <source>Use</source>
        <translation>Benutzen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="97"/>
        <source> KB/s</source>
        <translation>KB/s</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="293"/>
        <source>Show dual progression</source>
        <translation>Zeige dualen Fortschritt</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="245"/>
        <source>Show speed as main information</source>
        <translation>Zeige Geschwindigkeit als Information</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="80"/>
        <source>At the end of the copy</source>
        <translation>Am Ende des Kopiervorgangs</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="57"/>
        <source>Minimize on close to systray</source>
        <translation>Beim Schließen ins Systray minimieren</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="110"/>
        <source>Start with the &quot;more button&quot; pushed</source>
        <translation>Standardmäßig &quot;Mehr&quot; Informationen anzeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="313"/>
        <source>Progression color</source>
        <translation>Farbe des Fortschrittsbalken</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="239"/>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="303"/>
        <source>Show progression in the title</source>
        <translation>Fortschritt im Fenstertitel zeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="277"/>
        <source>Display</source>
        <translation>Anzeige</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="117"/>
        <source>Start minimized</source>
        <translation>Minimiert starten</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="70"/>
        <location filename="../../themesOptions.ui" line="87"/>
        <source>Limit copy speed to</source>
        <translation>Limitiere Kopiergeschwindigkeit auf</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="283"/>
        <source>Speed with progress bar</source>
        <translation>Geschwindigkeit mit Fortschrittsbalken</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="332"/>
        <source>Click to edit the color</source>
        <translation>Zum Bearbeiten der Farbe klicken</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="137"/>
        <source>Always on top</source>
        <translation>Fenster immer im Vordergrund halten</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="144"/>
        <source>Position at start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="204"/>
        <source>Dark UI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="212"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="217"/>
        <source>Save as previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="222"/>
        <source>At Center</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
